###############
Advanced Topics
###############

.. toctree::
    :maxdepth: 2

    algebra_performance.rst
    location_arithmetic.rst
    algebra_definition.rst
    center.rst
    debugging_logging.rst
